<?php

namespace Drupal\pagedesigner_block_adaptable\Plugin\views\filter;

use Drupal\views\Plugin\views\display\DisplayPluginBase;
use Drupal\views\Plugin\views\filter\InOperator;
use Drupal\views\ViewExecutable;

/**
 * Filters by nid or status of project.
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("nid_views_filter")
 * @deprecated in project:2.1.0 and is removed from project:3.0.0 Use
 *   pba_entity_filter instead.
 * @see https://www.drupal.org/project/pagedesigner_block_adaptable/issues/3366526
 */
class NidViewsFilter extends InOperator {

  /**
   * The current display.
   *
   * @var string
   *   The current display of the view.
   */
  protected $currentDisplay;

  /**
   * {@inheritdoc}
   */
  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
    parent::init($view, $display, $options);
    $this->valueTitle = $this->t('Filter by nid');
    $this->definition['options callback'] = [$this, 'generateOptions'];
    $this->currentDisplay = $view->current_display;
  }

  /**
   * Helper function that generates the options.
   *
   * @return array
   *   An array of node titles, keyed by their ids.
   */
  public function generateOptions() {
    $options = [];
    $filters = $this->view->getDisplay()->getOption('filters');
    $bundleFilter = EntityFilterBase::getBundles(['filters' => $filters]);
    $type = \Drupal::entityTypeManager()->getDefinition('node');
    $data = EntityFilterBase::getData($type, $bundleFilter, ['title']);
    $options = [];
    foreach ($data as $key => $record) {
      $options[$key] = $record->title;
    }
    return $options;
  }

  /**
   * {@inheritDoc}
   */
  public function query() {
    if (!empty($this->value)) {
      $this->query->addWhere('AND', 'node_field_data.nid', $this->value, 'IN');
    }
  }

}
